prainsa\.plotly\_plot package
=============================

Submodules
----------

prainsa\.plotly\_plot\.plotly\_plot module
------------------------------------------

.. automodule:: prainsa.plotly_plot.plotly_plot
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prainsa.plotly_plot
    :members:
    :undoc-members:
    :show-inheritance:
